stripe library for django

|pypi| |docs| |build-status| |coverage| |license|

stripe-django strives to be a perfect parity with Stripe's API.

Upcoming features
-----------------

- Synchronize Stripe API -> Models
- Link Stripe Customer's to *any* model including Users, Groups or any
  arbitrary model.
- Manage customer cards

.. |pypi| image:: https://img.shields.io/pypi/v/stripe-django.svg
    :alt: Python Package
    :target: http://badge.fury.io/py/stripe-django

.. |build-status| image:: https://img.shields.io/travis/develtech/stripe-django.svg
   :alt: Build Status
   :target: https://travis-ci.org/develtech/stripe-django

.. |coverage| image:: https://codecov.io/gh/develtech/stripe-django/branch/master/graph/badge.svg
    :alt: Code Coverage
    :target: https://codecov.io/gh/develtech/stripe-django

.. |license| image:: https://img.shields.io/github/license/develtech/stripe-django.svg
    :alt: License 

.. |docs| image:: https://readthedocs.org/projects/stripe-django/badge/?version=latest
    :alt: Documentation Status
    :scale: 100%
    :target: https://readthedocs.org/projects/stripe-django/
